@@ -10,21 +10,24 @@
 ##   version; incorporated herein by reference.
 ##
 ## -----------------------------------------------------------------------
-## $Id: makeinit.sh,v 1.3 2001/04/15 02:43:24 hpa Exp $
+## $Id: makeinit.sh,v 1.7 2002/02/11 00:44:58 hpa Exp $
 
 ##
 ## initrd make script for SuperRescue CD
 ##
 
-rm -f initrd initrd.gz
-rm -rf im ir
-mkdir -p ir
+rm -f work/initrd work/initrd.gz
+rm -rf work/im work/ir work/irtree
+mkdir -p work/ir
 find irtree -type f -name \*~ -print0 | xargs -0r rm -f
 
-dd if=/dev/zero of=initrd bs=1024 count=4096
-mke2fs -F initrd
-mount -t ext2 -o loop initrd ir
-cp -a irtree/. ir/.
-umount ir
+dd if=/dev/zero of=work/initrd bs=1024 count=4096
+mke2fs -F work/initrd
+tune2fs -c 0 -i 0 work/initrd
+mount -t ext2 -o loop work/initrd work/ir
+cp -a irtree work/irtree
+rm -rf work/irtree/RCS
+cp -a work/irtree/. work/ir/.
+umount work/ir
 sync
-gzip -9 initrd
+gzip -9 work/initrd
